Class Instantiation: :class:`mangadap.util.drpbitmask.DRPFitsBitMask`

=========  ===  ==================================
Key        Bit  Description                       
=========  ===  ==================================
NOCOV      0    No coverage in cube               
LOWCOV     1    Low coverage depth in cube        
DEADFIBER  2    Major contributing fiber is dead  
FORESTAR   3    Foreground star                   
DONOTUSE   10   Do not use this spaxel for science
=========  ===  ==================================

